# Generated by Django 4.2.6 on 2023-11-02 20:20

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('rps_milea', '0003_alter_mileachoices_options_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='mileachoices',
            name='model',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.contenttype'),
        ),
    ]
