{% extends "admin/base_site.html" %}
{% load i18n admin_urls static admin_modify %}
{% block extrahead %}
    {{ block.super }}
    <script src="{% url 'admin:jsi18n' %}"></script>
    <script src="{% static 'milea/js/masonry.pkgd.min.js'%}"></script>
    <script src="{% static 'milea/js/tom-select.complete.min.js'%}"></script>
    {{ media }}
{% endblock extrahead %}
{% block extrastyle %}
    {{ block.super }}
    <link rel="stylesheet" href="{% static 'admin/css/widgets.css' %}" />
    <link rel="stylesheet" href="{% static 'milea/css/form.css' %}" />
    <link rel="stylesheet" href="{% static 'milea/css/select2.css' %}" />
{% endblock extrastyle %}
{% if not is_popup %}
    {% block breadcrumbs %}
        <div class="page-pretitle">
            <ol class="breadcrumb">
                <li class="breadcrumb-item">
                    <a href="{% url 'admin:index' %}">{% translate "Home" %}</a>
                </li>
                <li class="breadcrumb-item">
                    <a href="{% url 'admin:app_list' app_label=opts.app_label %}">{{ opts.app_config.verbose_name }}</a>
                </li>
                <li class="breadcrumb-item {% if not has_view_permission %}active{% endif %}">
                    <a href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a>
                </li>
                <li class="breadcrumb-item active">
                    {% if add %}
                        <a href="#">{% blocktranslate with name=opts.verbose_name %}Add {{ name }}{% endblocktranslate %}</a>
                    {% else %}
                        <a href="#">{{ original|truncatewords:"18" }}</a>
                    {% endif %}
                </li>
            </ol>
        </div>
    {% endblock breadcrumbs %}
{% endif %}
{% block object-tools %}
    {% if change %}
        {% if not is_popup %}
            <ul class="object-tools">
                {% block object-tools-items %}
                    {% change_form_object_tools %}
                {% endblock object-tools-items %}
            </ul>
        {% endif %}
    {% endif %}
{% endblock object-tools %}
{% block content %}
    <div id="content-main">
        {% block form_top %}
        {% endblock form_top %}
        <form {% if has_file_field %}enctype="multipart/form-data"{% endif %}
              {% if form_url %}action="{{ form_url }}"{% endif %}
              method="post"
              id="{{ opts.model_name }}_form"
              novalidate>
            {% csrf_token %}
            <!--
            <div class="card-header">
                <h3 class="card-title">
                    {% if add %}
                        {% blocktranslate with name=opts.verbose_name %}Add {{ name }}{% endblocktranslate %}
                    {% else %}
                        {{ original|truncatewords:"30" }}
                    {% endif %}
                </h3>
            </div>
            -->
            <div>
                {% if is_popup %}<input type="hidden" name="{{ is_popup_var }}" value="1" />{% endif %}
                {% if to_field %}<input type="hidden" name="{{ to_field_var }}" value="{{ to_field }}" />{% endif %}
                {% if errors %}
                    <div class="row g-2 align-items-center">
                        <div class="col alert-messages">
                            <div class="alert alert-dismissible alert-danger" role="alert">
                                <div class="d-flex">
                                    <div>
                                        <i class="ti ti-alert-circle alert-icon display-6"></i>
                                    </div>
                                    <div>
                                        <h4 class="alert-title fs-3">
                                            {% if errors|length == 1 %}
                                                {% translate "Please correct the error below." %}
                                            {% else %}
                                                {% translate "Please correct the errors below." %}
                                            {% endif %}
                                        </h4>
                                        <div class="text-muted">{{ adminform.form.non_field_errors }}</div>
                                    </div>
                                </div>
                                <a class="btn-close" data-bs-dismiss="alert" aria-label="close"></a>
                            </div>
                        </div>
                    </div>
                {% endif %}
                {% block field_sets %}
                    <div class="row row-cards">
                        {% for fieldset in adminform %}
                            <div class="col-12 {{ fieldset.classes }}">{% include "admin/includes/fieldset.html" %}</div>
                        {% endfor %}
                    </div>
                {% endblock field_sets %}
                {% block after_field_sets %}
                {% endblock after_field_sets %}
                {% block inline_field_sets %}
                    {% for inline_admin_formset in inline_admin_formsets %}
                        {% include inline_admin_formset.opts.template %}
                    {% endfor %}
                {% endblock inline_field_sets %}
                {% block after_related_objects %}
                {% endblock after_related_objects %}
                {% block admin_change_form_document_ready %}
                    <script id="django-admin-form-add-constants" src="{% static 'admin/js/change_form.js' %}" {% if adminform and add %} data-model-name="{{ opts.model_name }}"{% endif %} async>
                    </script>
                {% endblock admin_change_form_document_ready %}
                {# JavaScript for prepopulated fields #}
                {% prepopulated_fields_js %}
            </div>
            <div class="card mt-3">
                <div class="card-body">
                    {% block submit_buttons_bottom %}
                        {% submit_row %}
                    {% endblock submit_buttons_bottom %}
                </div>
            </div>
        </form>
    </div>
{% endblock content %}
