{% for name, value in widget.attrs.items %}
    {% if value is not False and name != 'class' %}
        {{ name }}
        {% if value is not True %}="{{ value|stringformat:'s' }}"{% endif %}
    {% endif %}
{% endfor %}
