{% load i18n static milea_tags %}
<!DOCTYPE html>
<!--
* The MILEA Framework
* by red pepper services - Webdesign und IT-Dienstleistungen aus Vorarlberg
* @version {% milea_setting "FW_VERSION" %}
* @link https://www.red-pepper.at
* Copyright 2022-2023 red pepper Services e.U.
-->
<html lang="{{ LANGUAGE_CODE|default:'en-us' }}" dir="ltr">
    <head>
        <!-- Meta -->
        <meta charset="utf-8" />
        <meta name="viewport"
              content="width=device-width, initial-scale=1, viewport-fit=cover"/>
        <meta http-equiv="X-UA-Compatible" content="ie=edge" />
        <meta name="description" content="{% milea_setting "FW_NAME" %}" />
        <meta name="keywords" content="" />
        <link rel="icon" href="{% custom_static 'img/favicon.ico' %}" />
        {% block blockbots %}
            <meta name="robots" content="NONE,NOARCHIVE" />
        {% endblock blockbots %}
        {% block extrahead %}
        {% endblock extrahead %}
        <!-- Title -->
        <title>
            {% block title %}
                rps-django-template
            {% endblock title %}
        </title>
        <!-- CSS -->
        <link rel="stylesheet" href="{% static 'milea/css/tabler.css' %}" />
        <link rel="stylesheet" href="{% static 'milea/css/tabler-icons.css' %}" />
        <link rel="stylesheet" href="{% static 'milea/css/custom.css' %}" />
        {% block extrastyle %}
        {% endblock extrastyle %}
    </head>
    <body class="border-top-wide border-primary d-flex flex-column theme-dark"
          data-admin-utc-offset="{% now "Z" %}">
        <div class="page page-center">
            <div class="container container-normal py-4">
                {% block content %}
                    {{ content }}
                {% endblock content %}
            </div>
        </div>
        <!-- JS -->
        <script src="{% static 'milea/js/tabler.js' %}"></script>
        <script src="{% static 'milea/js/custom.js' %}"></script>
    </body>
</html>
