.datetimeshortcuts {
    display: flex;
    align-items: center;
    padding: 0.4375rem 0.75rem;
    font-size: 0.875rem;
    font-weight: 400;
    line-height: 1.4285714286;
    color: var(--tblr-muted);
    text-align: center;
    white-space: nowrap;
    background-color: #f8fafc;
    border: var(--tblr-border-width) solid var(--tblr-border-color);
    border-radius: var(--tblr-border-radius);
}

.input-group-lg > .datetimeshortcuts {
  padding: 0.5rem 0.75rem;
  font-size: 1.25rem;
  border-radius: 8px;
}

.input-group-sm > .datetimeshortcuts {
  padding: 0.125rem 0.25rem;
  font-size: 0.75rem;
  border-radius: 2px;
}

@media not print {
    @media (prefers-color-scheme: dark) {
        .theme-dark-auto .input-group-flat .datetimeshortcuts {
            background-color: #1a2234;
          }
          .theme-dark-auto .datetimeshortcuts {
            border-color: #243049;
          }
          .theme-dark-auto .datetimeshortcuts {
            background: transparent;
          }
    }
}
.input-group-flat:focus-within .datetimeshortcuts {
    border-color: #90b5e2 !important;
}
.input-group-flat .datetimeshortcuts {
    background: var(--tblr-bg-forms);
    transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
}
.input-group-flat .datetimeshortcuts:first-child {
    padding-right: 0;
}
.input-group-flat .datetimeshortcuts:last-child {
    padding-left: 0;
}

/* Fix Sonstiges */

.related-widget-wrapper {
    float: inherit;
}

/* Fix Calendar Form Widget */

.datetimeshortcuts .clock-icon, .datetimeshortcuts .date-icon {
    vertical-align: sub;
}

.calendar table {
    caption-side: top;
}

.clockbox {
    background: #eee;
    width: 16em;
}

.clockbox .calendar-cancel{
    background: rgb(201, 200, 200);
}

.calendarbox .calendarnav-previous, .calendarbox .calendarnav-next {
    top: 13px;
}

.calendar caption, .calendar-shortcuts {
    background: #eee;
}

.calendar td a:focus, .timelist a:focus, .calendar td a:hover, .timelist a:hover {
    color: var(--tblr-link-color);
}

.theme-dark .calendar table, .theme-dark .clockbox {
    background: var(--tblr-bg-surface);
}

.theme-dark .calendar caption, .theme-dark .calendar-shortcuts, .theme-dark .calendar-cancel {
    background: var(--tblr-bg-surface);
    color: #eee;
}

.theme-dark .calendar-cancel a {
    color: #eee;
}

table .delete input:checked {
    background-color: #d63939;
}
