{% extends "admin/base_site.html" %}
{% load i18n static milea_tags %}
{% block breadcrumbs %}
    <div class="page-pretitle">
        <ol class="breadcrumb">
            <li class="breadcrumb-item">
                <a href="{% url 'admin:index' %}">{% translate "Home" %}</a>
            </li>
        </ol>
    </div>
{% endblock breadcrumbs %}
{% block content %}
    {% if app_label %}
        <div id="content-main">{% include "admin/app_list.html" with app_list=app_list show_changelinks=True %}</div>
    {% else %}
        <div id="content-main">

            <div class="col-12">
                <div class="card card-md">
                    <div class="card-stamp card-stamp-lg">
                        <div class="card-stamp-icon bg-primary">
                            <svg xmlns="http://www.w3.org/2000/svg" class="icon icon-tabler icon-tabler-quote" width="24" height="24" viewBox="0 0 24 24" stroke-width="2" stroke="currentColor" fill="none" stroke-linecap="round" stroke-linejoin="round">
                            <path stroke="none" d="M0 0h24v24H0z" fill="none"/>
                            <path d="M10 11h-4a1 1 0 0 1 -1 -1v-3a1 1 0 0 1 1 -1h3a1 1 0 0 1 1 1v6c0 2.667 -1.333 4.333 -4 5" />
                            <path d="M19 11h-4a1 1 0 0 1 -1 -1v-3a1 1 0 0 1 1 -1h3a1 1 0 0 1 1 1v6c0 2.667 -1.333 4.333 -4 5" />
                            </svg>
                        </div>
                    </div>
                    <div class="card-body">
                        <div class="row align-items-center">
                            <div class="col-10">
                            <h3 class="h1">{% translate "Welcome" %} {{ request.user }}</h3>
                                <div class="markdown text-secondary">
                                    {% get_random_quote as random_quote %}
                                    <blockquote>{{ random_quote.q }} — 
                                        <em>{{ random_quote.a }}</em>
                                    </blockquote>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div> 

        </div>
    {% endif %}
{% endblock content %}
