{% load i18n %}
<div class="navbar-expand-md">
    <div class="collapse navbar-collapse" id="navbar-menu">
        <div class="navbar navbar-light">
            <div class="container-xl">
                <ul class="navbar-nav">
                    {% include "admin/app_menu_list.html" with app_list=available_apps show_changelinks=False %}
                </ul>
            </div>
        </div>
    </div>
</div>
