{% load i18n admin_urls %}
{% block object-tools-items %}
    {% url opts|admin_urlname:'history' original.pk|admin_urlquote as history_url %}
    <a href="{% add_preserved_filters history_url %}"
       class="historylink btn btn-primary">{% translate "History" %}</a>
    {% if has_absolute_url %}
        <a href="{{ absolute_url }}" class="viewsitelink btn btn-success">{% translate "View on site" %}</a>
    {% endif %}
{% endblock object-tools-items %}
