# Generated by Django 4.1.5 on 2023-10-09 07:54

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='MileaChoices',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_active', models.BooleanField(db_index=True, default=True, verbose_name='Active')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created at')),
                ('updated_at', models.DateTimeField(auto_now=True, verbose_name='Updated at')),
                ('category', models.CharField(max_length=64, verbose_name='Category')),
                ('display', models.CharField(max_length=64, verbose_name='Display name')),
                ('color', models.CharField(choices=[('blue', 'Blue'), ('azure', 'Azure'), ('indigo', 'Indigo'), ('purple', 'Purple'), ('pink', 'Pink'), ('red', 'Red'), ('orange', 'Orange'), ('yellow', 'Yellow'), ('lime', 'Lime'), ('green', 'Green'), ('teal', 'Teal'), ('cyan', 'Cyan'), ('dark', 'Black'), ('muted', 'Gray')], max_length=16, verbose_name='Color')),
                ('value', models.SlugField(editable=False)),
                ('created_by', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(app_label)s_%(class)s_created_by', to=settings.AUTH_USER_MODEL, verbose_name='Created by')),
                ('updated_by', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='%(app_label)s_%(class)s_updated_by', to=settings.AUTH_USER_MODEL, verbose_name='Updated by')),
            ],
            options={
                'verbose_name': 'Selection',
                'verbose_name_plural': 'Selection boxes',
                'ordering': ['category', 'value'],
            },
        ),
    ]
