#navbar-menu .navbar-nav .nav-link-icon i {
	display: block;
	height: 100%;
	margin-top: -1px;
}

.page-title {
    margin-top: 5px;
}

.text-inherit {
	color: inherit !important;
}

.hidden {
	display: none !important;
}

.alert-messages .alert {
	padding: 0.5rem;
}

.alert-messages .alert-title {
	line-height: 2.15rem;
	margin-bottom: 0;
}

.empty-form {
	display: none;
}

.inline-group .tabular td.original {
	height: 80px;
}

.inline-group .tabular td.original p {
	margin-top: 0;
	margin-bottom: 0;
	color: var(--tblr-table-bg);
}

tbody a:hover {
	text-decoration: none;
}

@media (min-width: 1600px) {

	.container-xxl,
	.container-xl,
	.container-lg,
	.container-md,
	.container-sm,
	.container {
		max-width: 1560px;
	}
}

.datetime input, .form-row .datetime input.vDateField, .form-row .datetime input.vTimeField {
	margin-left: 0 !important;
	margin-bottom: 0 !important;
}

/*=========================================================================================
	Table
==========================================================================================*/
.table-filter-card .subheader {
	font-size: 0.725rem;
}

.table-filter-card .list-group-item {
	padding: 0.3rem 1.55rem;
}

.list-group-item+.list-group-item.important.active {
	color: #d63939;
}

.table thead th,
.markdown>table thead th {
	font-size: 0.725rem;
}

.table thead tr .column-is_active_badge {
	width: 0.25rem!important;
}

.table tbody tr .field-is_active_badge {
	text-align: center;
}
