{% extends "admin/base.html" %}
{% block title %}
    {% if subtitle %}{{ subtitle }} |{% endif %}
    {{ title }} | {{ site_title|default:_('Django site admin') }}
{% endblock title %}
{% block nav-global %}
{% endblock nav-global %}
