<div class="datetime row g-2">
    <div class="col">
  {{ date_label }} {% with widget=widget.subwidgets.0 %}{% include widget.template_name %}{% endwith %}
    </div>
    <div class="col">
  {{ time_label }} {% with widget=widget.subwidgets.1 %}{% include widget.template_name %}{% endwith %}
    </div>
</div>
