{% if widget.type == 'hidden' %}
    <input type="hidden"
           name="{{ widget.name }}"
           {% if widget.value != None %} value="{{ widget.value|stringformat:'s' }}"{% endif %}
           {% include "django/forms/widgets/attrs.html" %}
           {% include "django/forms/widgets/classes.html" %}/>
{% else %}
    <div {% if 'vDateField' in widget.attrs.class or 'vTimeField' in widget.attrs.class %} class="input-group input-group-flat" {% else %} class="input-group" {% endif %}>
        <input type="{{ widget.type }}"
               name="{{ widget.name }}"
               {% if widget.value != None %} value="{{ widget.value|stringformat:'s' }}"{% endif %}
               {% include "django/forms/widgets/attrs.html" %}
               {% include "django/forms/widgets/classes.html" %}/>
    </div>
{% endif %}
