# Generated by Django 4.2.6 on 2023-11-02 19:20

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('rps_milea', '0002_alter_mileachoices_created_by_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='mileachoices',
            options={'ordering': ['model', 'value'], 'verbose_name': 'Selection box', 'verbose_name_plural': 'Selection boxes'},
        ),
        migrations.RenameField(
            model_name='mileachoices',
            old_name='category',
            new_name='model',
        ),
    ]
