{% extends "admin/change_form.html" %}
{% load i18n %}

{% block form_top %}
    {% if not is_popup %}
        <div class="alert alert-info" role="alert">
            {% translate "First, enter a username and password. Then, you’ll be able to edit more user options." %}
        </div>
    {% else %}
        <div class="alert alert-info" role="alert">{% translate "Enter a username and password." %}</div>
    {% endif %}
{% endblock form_top %}
