<textarea name="{{ widget.name }}" data-bs-toggle="autosize" {% include "django/forms/widgets/attrs.html" %} {% include "django/forms/widgets/classes.html" %}>
{% if widget.value %}{{ widget.value }}{% endif %}</textarea>
